@@ -1,14 +1,6 @@
 """
 Various project constants.
 """
-from pathlib import Path
-
-# Path to handsdown root directory.
-HANDSDOWN_PATH = Path(__file__)
-
-# Path to `assets` directory from root.
-ASSETS_PATH = HANDSDOWN_PATH / "assets"
-
 # Global `logging.Logger` name.
 LOGGER_NAME = "handsdown"
 
