@@ -7,8 +7,7 @@ from typing import Optional
 from handsdown.settings import LOGGER_NAME
 
 
-def get_logger(level=None):
-    # type: (Optional[int]) -> logging.Logger
+def get_logger(level: Optional[int] = None) -> logging.Logger:
     """
     Get stdout stream logger.
 
@@ -23,9 +22,7 @@ def get_logger(level=None):
         logger.setLevel(level)
 
     if not logger.handlers:
-        formatter = logging.Formatter(
-            fmt="%(levelname)-8s %(message)s", datefmt="%H:%M:%S"
-        )
+        formatter = logging.Formatter(fmt="%(levelname)-8s %(message)s", datefmt="%H:%M:%S")
         handler = logging.StreamHandler()
         if level is not None:
             handler.setLevel(level)
